==> cord_client_python-0.0.8-py3-none-any.whl: tests/test_data/img_group_test_blurb.py <==
IMG_GROUP_TEST_BLURB = {
    "label_hash": "5fbba385-4918-4eee-85a8-8b7a2e71dd16",
    "data_title": "image-group-f5ef4",
    "data_type": "img_group",
    "data_units": {
        "76888dd3-1160-4ba9-a638-dacb92e54e3c": {
            "data_hash": "76888dd3-1160-4ba9-a638-dacb92e54e3c",
            "data_title": "apple10.jpg",
            "data_link": "",
            "data_type": "image/jpg",
            "labels": {
                "objects": [
                    {
                        "name": "Apple",
                        "color": "#FE9200",
                        "shape": "bounding_box",
                        "value": "apple",
                        "createdAt": "Thu, 18 Feb 2021 22:24:59 GMT",
                        "createdBy": "robot@cord.tech",
                        "confidence": 1,
                        "objectHash": "0eaa81ee-77e0-4f5d-98e5-62ad29030263",
                        "featureHash": "b84a4d38-11be-424f-a92b-44f11e14c905",
                        "lastEditedAt": "Thu, 18 Feb 2021 22:25:01 GMT",
                        "lastEditedBy": "robot@cord.tech",
                        "manualAnnotation": True,
                        "boundingBox": {
                            "h": 0.510556621880998,
                            "w": 0.262472885032538,
                            "x": 0.3392590835140998,
                            "y": 0.21246400858756448,
                        },
                    }
                ],
                "classifications": [],
            },
        },
        "9211588c-709e-436a-b904-074e557aacb0": {
            "data_hash": "9211588c-709e-436a-b904-074e557aacb0",
            "data_title": "apple9.jpg",
            "data_link": "",
            "data_type": "image/jpg",
            "labels": {
                "objects": [
                    {
                        "name": "Apple",
                        "color": "#FE9200",
                        "shape": "bounding_box",
                        "value": "apple",
                        "createdAt": "Thu, 18 Feb 2021 22:25:02 GMT",
                        "createdBy": "robot@cord.tech",
                        "confidence": 1,
                        "objectHash": "0eaa81ee-77e0-4f5d-98e5-62ad29030263",
                        "featureHash": "b84a4d38-11be-424f-a92b-44f11e14c905",
                        "lastEditedAt": "Thu, 18 Feb 2021 22:25:05 GMT",
                        "lastEditedBy": "robot@cord.tech",
                        "manualAnnotation": True,
                        "boundingBox": {
                            "h": 0.510556621880998,
                            "w": 0.262472885032538,
                            "x": 0.3490204718004339,
                            "y": 0.23741602394265082,
                        },
                    }
                ],
                "classifications": [],
            },
        },
        "1dbc6787-3547-4764-b697-0c5a27e575b9": {
            "data_hash": "1dbc6787-3547-4764-b697-0c5a27e575b9",
            "data_title": "apple8.jpg",
            "data_link": "",
            "data_type": "image/jpg",
            "labels": {
                "objects": [
                    {
                        "name": "Apple",
                        "color": "#FE9200",
                        "shape": "bounding_box",
                        "value": "apple",
                        "createdAt": "Thu, 18 Feb 2021 22:25:06 GMT",
                        "createdBy": "robot@cord.tech",
                        "confidence": 1,
                        "objectHash": "0eaa81ee-77e0-4f5d-98e5-62ad29030263",
                        "featureHash": "b84a4d38-11be-424f-a92b-44f11e14c905",
                        "lastEditedAt": "Thu, 18 Feb 2021 22:25:12 GMT",
                        "lastEditedBy": "robot@cord.tech",
                        "manualAnnotation": True,
                        "boundingBox": {
                            "h": 0.4817658349328214,
                            "w": 0.2472885032537961,
                            "x": 0.3522742678958785,
                            "y": 0.23933540973919604,
                        },
                    }
                ],
                "classifications": [],
            },
        },
        "b2d70700-3ee8-4cd0-8515-7cf772fab0e2": {
            "data_hash": "b2d70700-3ee8-4cd0-8515-7cf772fab0e2",
            "data_title": "apple7.jpg",
            "data_link": "",
            "data_type": "image/jpg",
            "labels": {
                "objects": [
                    {
                        "name": "Apple",
                        "color": "#FE9200",
                        "shape": "bounding_box",
                        "value": "apple",
                        "createdAt": "Thu, 18 Feb 2021 22:25:13 GMT",
                        "createdBy": "robot@cord.tech",
                        "confidence": 1,
                        "objectHash": "0eaa81ee-77e0-4f5d-98e5-62ad29030263",
                        "featureHash": "b84a4d38-11be-424f-a92b-44f11e14c905",
                        "lastEditedAt": "Thu, 18 Feb 2021 22:25:21 GMT",
                        "lastEditedBy": "robot@cord.tech",
                        "manualAnnotation": True,
                        "boundingBox": {
                            "h": 0.510556621880998,
                            "w": 0.28199566160520606,
                            "x": 0.3989120119305857,
                            "y": 0.19710892221520365,
                        },
                    }
                ],
                "classifications": [],
            },
        },
        "5283863a-ebae-4250-a74f-f0dd9f711ab8": {
            "data_hash": "5283863a-ebae-4250-a74f-f0dd9f711ab8",
            "data_title": "apple6.jpg",
            "data_link": "",
            "data_type": "image/jpg",
            "labels": {
                "objects": [
                    {
                        "name": "Apple",
                        "color": "#FE9200",
                        "shape": "bounding_box",
                        "value": "apple",
                        "createdAt": "Thu, 18 Feb 2021 22:25:23 GMT",
                        "createdBy": "robot@cord.tech",
                        "confidence": 1,
                        "objectHash": "0eaa81ee-77e0-4f5d-98e5-62ad29030263",
                        "featureHash": "b84a4d38-11be-424f-a92b-44f11e14c905",
                        "lastEditedAt": "Thu, 18 Feb 2021 22:25:30 GMT",
                        "lastEditedBy": "robot@cord.tech",
                        "manualAnnotation": True,
                        "boundingBox": {
                            "h": 0.3973128598848369,
                            "w": 0.21583514099783085,
                            "x": 0.45748034164858997,
                            "y": 0.27388435407700784,
                        },
                    }
                ],
                "classifications": [],
            },
        },
        "3a611306-618a-4e0a-ad9b-ee27500c74bc": {
            "data_hash": "3a611306-618a-4e0a-ad9b-ee27500c74bc",
            "data_title": "apple5.jpg",
            "data_link": "",
            "data_type": "image/jpg",
            "labels": {
                "objects": [
                    {
                        "name": "Apple",
                        "color": "#FE9200",
                        "shape": "bounding_box",
                        "value": "apple",
                        "createdAt": "Thu, 18 Feb 2021 22:25:37 GMT",
                        "createdBy": "robot@cord.tech",
                        "confidence": 1,
                        "objectHash": "0eaa81ee-77e0-4f5d-98e5-62ad29030263",
                        "featureHash": "b84a4d38-11be-424f-a92b-44f11e14c905",
                        "lastEditedAt": "Thu, 18 Feb 2021 22:25:38 GMT",
                        "lastEditedBy": "robot@cord.tech",
                        "manualAnnotation": True,
                        "boundingBox": {
                            "h": 0.5585412667946257,
                            "w": 0.3145336225596529,
                            "x": 0.39782741323210413,
                            "y": 0.1836732216393879,
                        },
                    }
                ],
                "classifications": [],
            },
        },
        "5b6656de-e7ac-49b1-bccb-738b9be289aa": {
            "data_hash": "5b6656de-e7ac-49b1-bccb-738b9be289aa",
            "data_title": "apple4.jpg",
            "data_link": "",
            "data_type": "image/jpg",
            "labels": {
                "objects": [
                    {
                        "name": "Apple",
                        "color": "#FE9200",
                        "shape": "bounding_box",
                        "value": "apple",
                        "createdAt": "Thu, 18 Feb 2021 22:25:46 GMT",
                        "createdBy": "robot@cord.tech",
                        "confidence": 1,
                        "objectHash": "0eaa81ee-77e0-4f5d-98e5-62ad29030263",
                        "featureHash": "b84a4d38-11be-424f-a92b-44f11e14c905",
                        "manualAnnotation": True,
                        "boundingBox": {
                            "h": 0.5642994241842612,
                            "w": 0.3145336225596529,
                            "x": 0.3989120119305857,
                            "y": 0.17599567845320746,
                        },
                    }
                ],
                "classifications": [],
            },
        },
        "81d9592d-6d74-4196-af2e-df877be3d663": {
            "data_hash": "81d9592d-6d74-4196-af2e-df877be3d663",
            "data_title": "apple3.jpg",
            "data_link": "",
            "data_type": "image/jpg",
            "labels": {
                "objects": [
                    {
                        "name": "Apple",
                        "color": "#FE9200",
                        "shape": "bounding_box",
                        "value": "apple",
                        "createdAt": "Thu, 18 Feb 2021 22:25:53 GMT",
                        "createdBy": "robot@cord.tech",
                        "confidence": 1,
                        "objectHash": "0eaa81ee-77e0-4f5d-98e5-62ad29030263",
                        "featureHash": "b84a4d38-11be-424f-a92b-44f11e14c905",
                        "manualAnnotation": True,
                        "boundingBox": {
                            "h": 0.5163147792706334,
                            "w": 0.2809110629067245,
                            "x": 0.37396624186550975,
                            "y": 0.26620681089082743,
                        },
                    }
                ],
                "classifications": [],
            },
        },
        "1aaa5c7c-c880-4114-b60c-19ab737d73eb": {
            "data_hash": "1aaa5c7c-c880-4114-b60c-19ab737d73eb",
            "data_title": "apple2.jpg",
            "data_link": "",
            "data_type": "image/jpg",
            "labels": {
                "objects": [
                    {
                        "name": "Apple",
                        "color": "#FE9200",
                        "shape": "bounding_box",
                        "value": "apple",
                        "createdAt": "Thu, 18 Feb 2021 22:25:59 GMT",
                        "createdBy": "robot@cord.tech",
                        "confidence": 1,
                        "objectHash": "0eaa81ee-77e0-4f5d-98e5-62ad29030263",
                        "featureHash": "b84a4d38-11be-424f-a92b-44f11e14c905",
                        "manualAnnotation": True,
                        "boundingBox": {
                            "h": 0.45105566218809984,
                            "w": 0.26355748373101956,
                            "x": 0.413011795010846,
                            "y": 0.2201415517737449,
                        },
                    }
                ],
                "classifications": [],
            },
        },
        "960ae3d8-eff0-4f30-ad57-e43a95a9b323": {
            "data_hash": "960ae3d8-eff0-4f30-ad57-e43a95a9b323",
            "data_title": "apple1.jpg",
            "data_link": "",
            "data_type": "image/jpg",
            "labels": {
                "objects": [
                    {
                        "name": "Apple",
                        "color": "#FE9200",
                        "shape": "bounding_box",
                        "value": "apple",
                        "createdAt": "Thu, 18 Feb 2021 22:26:05 GMT",
                        "createdBy": "robot@cord.tech",
                        "confidence": 1,
                        "objectHash": "0eaa81ee-77e0-4f5d-98e5-62ad29030263",
                        "featureHash": "b84a4d38-11be-424f-a92b-44f11e14c905",
                        "manualAnnotation": True,
                        "boundingBox": {
                            "h": 0.399232245681382,
                            "w": 0.23210412147505421,
                            "x": 0.4162655911062907,
                            "y": 0.29307821204245893,
                        },
                    }
                ],
                "classifications": [],
            },
        },
        "object_answers": {
            "0eaa81ee-77e0-4f5d-98e5-62ad29030263": {
                "objectHash": "0eaa81ee-77e0-4f5d-98e5-62ad29030263",
                "classifications": [],
            }
        },
        "classification_answers": {},
    },
    "label_status": "LABELLED",
}

==> cord_client_python-0.1.6-py3-none-any.whl: tests/test_data/img_group_test_blurb.py <==
IMG_GROUP_TEST_BLURB = {
    "label_hash": "5fbba385-4918-4eee-85a8-8b7a2e71dd16",
    "data_title": "image-group-f5ef4",
    "data_type": "img_group",
    "data_units": {
        "76888dd3-1160-4ba9-a638-dacb92e54e3c": {
            "data_hash": "76888dd3-1160-4ba9-a638-dacb92e54e3c",
            "data_title": "apple10.jpg",
            "data_link": "",
            "data_type": "image/jpg",
            "data_sequence": "0",
            "labels": {
                "objects": [
                    {
                        "name": "Apple",
                        "color": "#FE9200",
                        "shape": "bounding_box",
                        "value": "apple",
                        "createdAt": "Thu, 18 Feb 2021 22:24:59 GMT",
                        "createdBy": "robot@cord.tech",
                        "confidence": 1,
                        "objectHash": "0eaa81ee-77e0-4f5d-98e5-62ad29030263",
                        "featureHash": "b84a4d38-11be-424f-a92b-44f11e14c905",
                        "lastEditedAt": "Thu, 18 Feb 2021 22:25:01 GMT",
                        "lastEditedBy": "robot@cord.tech",
                        "manualAnnotation": True,
                        "boundingBox": {
                            "h": 0.510556621880998,
                            "w": 0.262472885032538,
                            "x": 0.3392590835140998,
                            "y": 0.21246400858756448,
                        },
                    }
                ],
                "classifications": [],
            },
        },
        "9211588c-709e-436a-b904-074e557aacb0": {
            "data_hash": "9211588c-709e-436a-b904-074e557aacb0",
            "data_title": "apple9.jpg",
            "data_link": "",
            "data_type": "image/jpg",
            "data_sequence": "1",
            "labels": {
                "objects": [
                    {
                        "name": "Apple",
                        "color": "#FE9200",
                        "shape": "bounding_box",
                        "value": "apple",
                        "createdAt": "Thu, 18 Feb 2021 22:25:02 GMT",
                        "createdBy": "robot@cord.tech",
                        "confidence": 1,
                        "objectHash": "0eaa81ee-77e0-4f5d-98e5-62ad29030263",
                        "featureHash": "b84a4d38-11be-424f-a92b-44f11e14c905",
                        "lastEditedAt": "Thu, 18 Feb 2021 22:25:05 GMT",
                        "lastEditedBy": "robot@cord.tech",
                        "manualAnnotation": True,
                        "boundingBox": {
                            "h": 0.510556621880998,
                            "w": 0.262472885032538,
                            "x": 0.3490204718004339,
                            "y": 0.23741602394265082,
                        },
                    }
                ],
                "classifications": [],
            },
        },
        "1dbc6787-3547-4764-b697-0c5a27e575b9": {
            "data_hash": "1dbc6787-3547-4764-b697-0c5a27e575b9",
            "data_title": "apple8.jpg",
            "data_link": "",
            "data_type": "image/jpg",
            "data_sequence": "2",
            "labels": {
                "objects": [
                    {
                        "name": "Apple",
                        "color": "#FE9200",
                        "shape": "bounding_box",
                        "value": "apple",
                        "createdAt": "Thu, 18 Feb 2021 22:25:06 GMT",
                        "createdBy": "robot@cord.tech",
                        "confidence": 1,
                        "objectHash": "0eaa81ee-77e0-4f5d-98e5-62ad29030263",
                        "featureHash": "b84a4d38-11be-424f-a92b-44f11e14c905",
                        "lastEditedAt": "Thu, 18 Feb 2021 22:25:12 GMT",
                        "lastEditedBy": "robot@cord.tech",
                        "manualAnnotation": True,
                        "boundingBox": {
                            "h": 0.4817658349328214,
                            "w": 0.2472885032537961,
                            "x": 0.3522742678958785,
                            "y": 0.23933540973919604,
                        },
                    }
                ],
                "classifications": [],
            },
        },
        "b2d70700-3ee8-4cd0-8515-7cf772fab0e2": {
            "data_hash": "b2d70700-3ee8-4cd0-8515-7cf772fab0e2",
            "data_title": "apple7.jpg",
            "data_link": "",
            "data_type": "image/jpg",
            "data_sequence": "3",
            "labels": {
                "objects": [
                    {
                        "name": "Apple",
                        "color": "#FE9200",
                        "shape": "bounding_box",
                        "value": "apple",
                        "createdAt": "Thu, 18 Feb 2021 22:25:13 GMT",
                        "createdBy": "robot@cord.tech",
                        "confidence": 1,
                        "objectHash": "0eaa81ee-77e0-4f5d-98e5-62ad29030263",
                        "featureHash": "b84a4d38-11be-424f-a92b-44f11e14c905",
                        "lastEditedAt": "Thu, 18 Feb 2021 22:25:21 GMT",
                        "lastEditedBy": "robot@cord.tech",
                        "manualAnnotation": True,
                        "boundingBox": {
                            "h": 0.510556621880998,
                            "w": 0.28199566160520606,
                            "x": 0.3989120119305857,
                            "y": 0.19710892221520365,
                        },
                    }
                ],
                "classifications": [],
            },
        },
        "5283863a-ebae-4250-a74f-f0dd9f711ab8": {
            "data_hash": "5283863a-ebae-4250-a74f-f0dd9f711ab8",
            "data_title": "apple6.jpg",
            "data_link": "",
            "data_type": "image/jpg",
            "data_sequence": "4",
            "labels": {
                "objects": [
                    {
                        "name": "Apple",
                        "color": "#FE9200",
                        "shape": "bounding_box",
                        "value": "apple",
                        "createdAt": "Thu, 18 Feb 2021 22:25:23 GMT",
                        "createdBy": "robot@cord.tech",
                        "confidence": 1,
                        "objectHash": "0eaa81ee-77e0-4f5d-98e5-62ad29030263",
                        "featureHash": "b84a4d38-11be-424f-a92b-44f11e14c905",
                        "lastEditedAt": "Thu, 18 Feb 2021 22:25:30 GMT",
                        "lastEditedBy": "robot@cord.tech",
                        "manualAnnotation": True,
                        "boundingBox": {
                            "h": 0.3973128598848369,
                            "w": 0.21583514099783085,
                            "x": 0.45748034164858997,
                            "y": 0.27388435407700784,
                        },
                    }
                ],
                "classifications": [],
            },
        },
        "3a611306-618a-4e0a-ad9b-ee27500c74bc": {
            "data_hash": "3a611306-618a-4e0a-ad9b-ee27500c74bc",
            "data_title": "apple5.jpg",
            "data_link": "",
            "data_type": "image/jpg",
            "data_sequence": "5",
            "labels": {
                "objects": [
                    {
                        "name": "Apple",
                        "color": "#FE9200",
                        "shape": "bounding_box",
                        "value": "apple",
                        "createdAt": "Thu, 18 Feb 2021 22:25:37 GMT",
                        "createdBy": "robot@cord.tech",
                        "confidence": 1,
                        "objectHash": "0eaa81ee-77e0-4f5d-98e5-62ad29030263",
                        "featureHash": "b84a4d38-11be-424f-a92b-44f11e14c905",
                        "lastEditedAt": "Thu, 18 Feb 2021 22:25:38 GMT",
                        "lastEditedBy": "robot@cord.tech",
                        "manualAnnotation": True,
                        "boundingBox": {
                            "h": 0.5585412667946257,
                            "w": 0.3145336225596529,
                            "x": 0.39782741323210413,
                            "y": 0.1836732216393879,
                        },
                    }
                ],
                "classifications": [],
            },
        },
        "5b6656de-e7ac-49b1-bccb-738b9be289aa": {
            "data_hash": "5b6656de-e7ac-49b1-bccb-738b9be289aa",
            "data_title": "apple4.jpg",
            "data_link": "",
            "data_type": "image/jpg",
            "data_sequence": "6",
            "labels": {
                "objects": [
                    {
                        "name": "Apple",
                        "color": "#FE9200",
                        "shape": "bounding_box",
                        "value": "apple",
                        "createdAt": "Thu, 18 Feb 2021 22:25:46 GMT",
                        "createdBy": "robot@cord.tech",
                        "confidence": 1,
                        "objectHash": "0eaa81ee-77e0-4f5d-98e5-62ad29030263",
                        "featureHash": "b84a4d38-11be-424f-a92b-44f11e14c905",
                        "manualAnnotation": True,
                        "boundingBox": {
                            "h": 0.5642994241842612,
                            "w": 0.3145336225596529,
                            "x": 0.3989120119305857,
                            "y": 0.17599567845320746,
                        },
                    }
                ],
                "classifications": [],
            },
        },
        "81d9592d-6d74-4196-af2e-df877be3d663": {
            "data_hash": "81d9592d-6d74-4196-af2e-df877be3d663",
            "data_title": "apple3.jpg",
            "data_link": "",
            "data_type": "image/jpg",
            "data_sequence": "7",
            "labels": {
                "objects": [
                    {
                        "name": "Apple",
                        "color": "#FE9200",
                        "shape": "bounding_box",
                        "value": "apple",
                        "createdAt": "Thu, 18 Feb 2021 22:25:53 GMT",
                        "createdBy": "robot@cord.tech",
                        "confidence": 1,
                        "objectHash": "0eaa81ee-77e0-4f5d-98e5-62ad29030263",
                        "featureHash": "b84a4d38-11be-424f-a92b-44f11e14c905",
                        "manualAnnotation": True,
                        "boundingBox": {
                            "h": 0.5163147792706334,
                            "w": 0.2809110629067245,
                            "x": 0.37396624186550975,
                            "y": 0.26620681089082743,
                        },
                    }
                ],
                "classifications": [],
            },
        },
        "1aaa5c7c-c880-4114-b60c-19ab737d73eb": {
            "data_hash": "1aaa5c7c-c880-4114-b60c-19ab737d73eb",
            "data_title": "apple2.jpg",
            "data_link": "",
            "data_type": "image/jpg",
            "data_sequence": "8",
            "labels": {
                "objects": [
                    {
                        "name": "Apple",
                        "color": "#FE9200",
                        "shape": "bounding_box",
                        "value": "apple",
                        "createdAt": "Thu, 18 Feb 2021 22:25:59 GMT",
                        "createdBy": "robot@cord.tech",
                        "confidence": 1,
                        "objectHash": "0eaa81ee-77e0-4f5d-98e5-62ad29030263",
                        "featureHash": "b84a4d38-11be-424f-a92b-44f11e14c905",
                        "manualAnnotation": True,
                        "boundingBox": {
                            "h": 0.45105566218809984,
                            "w": 0.26355748373101956,
                            "x": 0.413011795010846,
                            "y": 0.2201415517737449,
                        },
                    }
                ],
                "classifications": [],
            },
        },
        "960ae3d8-eff0-4f30-ad57-e43a95a9b323": {
            "data_hash": "960ae3d8-eff0-4f30-ad57-e43a95a9b323",
            "data_title": "apple1.jpg",
            "data_link": "",
            "data_type": "image/jpg",
            "data_sequence": "9",
            "labels": {
                "objects": [
                    {
                        "name": "Apple",
                        "color": "#FE9200",
                        "shape": "bounding_box",
                        "value": "apple",
                        "createdAt": "Thu, 18 Feb 2021 22:26:05 GMT",
                        "createdBy": "robot@cord.tech",
                        "confidence": 1,
                        "objectHash": "0eaa81ee-77e0-4f5d-98e5-62ad29030263",
                        "featureHash": "b84a4d38-11be-424f-a92b-44f11e14c905",
                        "manualAnnotation": True,
                        "boundingBox": {
                            "h": 0.399232245681382,
                            "w": 0.23210412147505421,
                            "x": 0.4162655911062907,
                            "y": 0.29307821204245893,
                        },
                    }
                ],
                "classifications": [],
            },
        },
    },
    "object_answers": {
        "0eaa81ee-77e0-4f5d-98e5-62ad29030263": {
            "objectHash": "0eaa81ee-77e0-4f5d-98e5-62ad29030263",
            "classifications": [],
        }
    },
    "classification_answers": {},
    "label_status": "LABELLED",
}
